@@ -174,6 +174,9 @@ sub _id_to_tmp_info_hash {
             next;
         }
         my $entries = $h_ref->{feed}{entry};
+        if ( ! defined $entries ) {
+            last; #
+        }
         $count_entries = @$entries;
         if ( ! $count_entries ) {
             last;
