@@ -21,6 +21,7 @@ use App::YTDL::Info_Print     qw( linefolded_print_info );
 use App::YTDL::Helper         qw( get_filename encode_stdout_lax encode_fs sanitize_for_path );
 use App::YTDL::History        qw( add_channel_to_history write_channel_history_to_file );
 use App::YTDL::Select_Quality qw( fmt_quality set_preferred_qualities );
+use App::YTDL::Options        qw( set_options );
 
 
 
@@ -61,11 +62,11 @@ sub get_download_infos {
                 $opt->{up}++;
                 $fmt_list = fmt_quality( $opt, $info, $fmt_list, $ex, $video_id );
                 if ( ! defined $fmt_list ) {
-                    my ( $delete, $append, $pref_qualities, $quit ) = ( 'Delete', 'Append', 'Preferred qualities', 'Quit' );
+                    my ( $delete, $append, $pref_qualities, $options, $quit ) = ( 'Delete', 'Append', 'Preferred qualities', 'Options', 'Quit' );
                     # Choose
                     my $choice = choose(
-                        [ undef, $quit, $delete, $append, $pref_qualities ],
-                        { prompt => 'Your choice: ', undef => 'Back' }
+                        [ undef, $quit, $delete, $append, $pref_qualities, $options ],
+                        { prompt => 'Your choice: ', default => 1, undef => 'Back' }
                     );
                     if ( ! defined $choice ) {
                         print up( $opt->{up} ), cldown;
@@ -73,9 +74,20 @@ sub get_download_infos {
                         next MENU;
                     }
                     elsif ( $choice eq $quit ) {
-                        print locate( 1, 1 ), cldown;
-                        say "Quit";
-                        exit;
+                        my $confirm = choose(
+                            [ undef, '  Confirm QUIT' ],
+                            { prompt => 'Your choice: ', default => 1, layout => 3, undef => '  MENU' }
+                        );
+                        if ( ! defined $confirm ) {
+                            print up( $opt->{up} ), cldown;
+                            $opt->{up} = 0;
+                            next MENU;
+                        }
+                        else {
+                            print locate( 1, 1 ), cldown;
+                            say "Quit";
+                            exit;
+                        }
                     }
                     elsif ( $choice eq $delete ) {
                         delete  $info->{$ex}{$video_id};
@@ -101,6 +113,13 @@ sub get_download_infos {
                         $opt->{up} = 0;
                         next MENU;
                     }
+                    elsif ( $choice eq $options ) {
+                        set_options( $opt );
+                        unshift @video_ids, $video_id;
+                        print up( $opt->{up} ), cldown;
+                        $opt->{up} = 0;
+                        next VIDEO;
+                    }
                 }
                 else {
                     last MENU;
