@@ -69,8 +69,8 @@ sub search_and_merge {
                 my $out = catfile $video_dir, $file_name;
                 if ( -f $out && ! $opt->{merge_overwrite} ) {
                     my $overwrite_ok = choose(
-                        [ 'NO merge', 'Merge and overwrite' ],
-                        { prompt => $out . ' already exists:', index => 1 }
+                        [ '  Skip', '  Overwrite' ],
+                        { prompt => 'Already exists: ' . $file_name, layout => 3, index => 1 }
                     );
                     if ( ! $overwrite_ok ) {
                         next VIDEO_ID;
@@ -101,7 +101,9 @@ sub search_and_merge {
             }
         }
     }
-    say 'Merged:';
+    if ( @merged ) {
+        say 'Merged:';
+    }
     for my $merged_file ( @merged ) {
         say ' ' .  $merged_file;
     }
