@@ -271,7 +271,7 @@ sub set_options {
                 my $prompt = 'Enable merge';
                 my $list = [
                     'NO',
-                    'Ask user',
+                    'Ask',
                     'YES'
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
